import DataTIC
from dataclasses import dataclass
import json
from mysql.connector import Error
import mysql.connector
from numpy import ndarray
from typing import Final
from wrapt_timeout_decorator import *


#import array
TABLE_1FIELD_NAME:Final = "id_RUN"
TABLE_2FIELD_NAME:Final = "ACSN"
TABLE_3FIELD_NAME:Final = "Date_Time"
TABLE_4FIELD_NAME:Final = "Thresholds_X_JSON"
TABLE_5FIELD_NAME:Final = "Thresholds_Y_JSON"
TABLE_6FIELD_NAME:Final = "TimeSlice_B1"
TABLE_7FIELD_NAME:Final = "Delay_B1"
TABLE_8FIELD_NAME:Final = "TimeSlice_B2"
TABLE_9FIELD_NAME:Final = "Delay_B2"
TABLE_10FIELD_NAME:Final = "DATA_X1_JSON"
TABLE_11FIELD_NAME:Final = "DATA_Y1_JSON"
TABLE_12FIELD_NAME:Final = "DATA_X2_JSON"
TABLE_13FIELD_NAME:Final = "DATA_Y2_JSON"
TABLE_14FIELD_NAME:Final = "Thresholds_GS_JSON"
TABLE_15FIELD_NAME:Final = "DATA_GS1_JSON"
TABLE_16FIELD_NAME:Final = "DATA_GS2_JSON"

@dataclass
class ParameterConnection:
    user: str = ""
    password: str = ""
    host: str = ""
    database: str = ""
    table: str = ""
    port: int = 0
    
    def getConfig(self):
        return {
            'user': self.user,
            'password': self.password,
            'host': self.host,
            'database': self.database,
            'port': self.port,
            'raise_on_warnings': True
            }

def openConnection(parameters):
    config = parameters.getConfig()
    return mysql.connector.connect(**config)
    
def getRecordByIdFirstbank(parameters, connector, id):
    select_record_query = "SELECT " + TABLE_3FIELD_NAME + "," + TABLE_6FIELD_NAME + "," + TABLE_7FIELD_NAME + "," + TABLE_10FIELD_NAME + "," + TABLE_11FIELD_NAME + "," + TABLE_15FIELD_NAME + " FROM " + parameters.table + " WHERE " + TABLE_1FIELD_NAME + " = " + str(id)
    with connector.cursor() as cursor:
        try:
            cursor.execute(select_record_query)
            result = cursor.fetchall()
            resultArray = ndarray()
            for i in range(0,result[0][3].size()):
                resultArray[i] = result[0][3][i] + result[0][4][i] + result[0][5][i]
            return DataTIC.DownloadData(
                id=id,
                dateTime=result[0][0],
                delay=result[0][2],
                timeslice=result[0][1],
                matrix=resultArray
                )
            #data = json.loads(result[0][0])
            #print (data[0])
            #print(data)
            #data = json.loads(result)
            
        except Error as e:
            print("Error while connecting to MySQL:", e)

def getRecordByIdSecondBank(parameters, connector, id):
    select_record_query = "SELECT " + TABLE_3FIELD_NAME + "," + TABLE_6FIELD_NAME + "," + TABLE_7FIELD_NAME + "," + TABLE_12FIELD_NAME + "," + TABLE_13FIELD_NAME + "," + TABLE_16FIELD_NAME + " FROM " + parameters.table + " WHERE " + TABLE_1FIELD_NAME + " = " + str(id)
    with connector.cursor() as cursor:
        try:
            cursor.execute(select_record_query)
            result = cursor.fetchall()
            resultArray = ndarray()
            for i in range(0,result[0][3].size()):
                resultArray[i] = result[0][3][i] + result[0][4][i] + result[0][5][i]
            return DataTIC.DownloadData(
                id=id,
                dateTime=result[0][0],
                delay=result[0][2],
                timeslice=result[0][1],
                matrix=resultArray
                )
            #data = json.loads(result[0][0])
            #print (data[0])
            #print(data)
            #data = json.loads(result)
            
        except Error as e:
            print("Error while connecting to MySQL:", e)
@timeout(1)
def parametersIsValid(parameters):
    config = parameters.getConfig()
    try:
        with mysql.connector.connect(**config) as connector:
            print(connector)
            return getCountRecords(parameters, connector) > 0
    except Error as e:
        print("Error while connecting to MySQL:", e)
        return 0
    
def getCountRecords(parameters, connector):
    cursor = connector.cursor()
    query = "SELECT COUNT(*) FROM " + parameters.table
    #print(query)
    cursor.execute(query)
    result = cursor.fetchall()
    print("Count:",result[0][0])
    cursor.close()
    return result[0][0]
        
if __name__ == "__main__":
    parameters = ParameterConnection(
        user = "viewer",
        password = "HereJustToSee",
        host = "ma-s.jinr.ru",
        database = "TIC",
        table = "session_test2",
        port = 3306
        )
    print(parametersIsValid(parameters))


import DataTIC
from dataclasses import dataclass
from numpy import array as ndarray
from numpy import sqrt
import numpy


def getMeasuredProfileTICDataByRawTICData(rawBlockData):
    npRawData = ndarray(rawBlockData.matrix)
    
    measureBlock = __measureProfile__(npRawData, rawBlockData.descriptionTICData.timeSlice)
    
    return DataTIC.MeasureProfileTICData(rawBlockData.descriptionTICData, 
                                         measureBlock.countPerSlice, 
                                         measureBlock.meanPerSlice, 
                                         measureBlock.sigmaPerSlice, 
                                         measureBlock.errorSigmaPerSlice, 
                                         measureBlock.timePerSlice, 
                                         measureBlock.numberPerChannel, 
                                         measureBlock.countPerChannel, 
                                         measureBlock.matrix)

def __measureProfile__(rawArray, timeSlice):
    countChannel = rawArray[0].size
    countSlice = len(rawArray)
    
    countPerSlice = numpy.zeros(countSlice)
    meanPerSlice = numpy.zeros(countSlice, float)
    sigmaPerSlice = numpy.zeros(countSlice, float)
    errorSigmaPerSlice = numpy.zeros(countSlice, float)
    timePerSlice = numpy.zeros(countSlice, float)
    
    numberPerChannel = numpy.arange(countChannel)
    countPerChannel = numpy.zeros(countChannel)
    
    for i in range(0,countSlice):
        countPerSlice[i] = numpy.sum(rawArray[i])
        meanPerSlice[i] = numpy.median(rawArray[i])
        sigmaPerSlice[i] = numpy.std(rawArray[i])
        errorSigmaPerSlice[i] = sigmaPerSlice[-1]/sqrt(countPerSlice[-1])
        timePerSlice[i] = 0 + timeSlice*i

        countPerChannel = countPerChannel + rawArray[i]
    
    for i in range (0, countChannel):
        numberPerChannel[i] = i + 1
    return __BlockMeasuredProfile__(countPerSlice, meanPerSlice, sigmaPerSlice, errorSigmaPerSlice, timePerSlice)

def getMeasuredCounterTICDataByRawTICData(rawBlockData):
    measureBlock = __measureCounter__(rawBlockData)
    
    return DataTIC.MeasureCounterTICData(rawBlockData.descriptionTICData,
                                         measureBlock.sum)
    
def __measureCounter__(rawArray):
    return __BlockMeasuredCounter__(rawArray.sum())
    
@dataclass
class __BlockMeasuredCounter__():
    sum:int
    
@dataclass
class __BlockMeasuredProfile__():
    countPerSlice:ndarray
    meanPerSlice:ndarray
    sigmaPerSlice:ndarray
    errorSigmaPerSlice:ndarray
    timePerSlice:ndarray
        
if __name__ == '__main__':
    i=5


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_ViewGraphicsDialog(object):
    def setupUi(self, ViewGraphicsDialog):
        ViewGraphicsDialog.setObjectName("ViewGraphicsDialog")
        ViewGraphicsDialog.resize(158, 200)
        ViewGraphicsDialog.setMinimumSize(QtCore.QSize(140, 200))
        self.verticalLayout = QtWidgets.QVBoxLayout(ViewGraphicsDialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.checkBoxMCPX1 = QtWidgets.QCheckBox(ViewGraphicsDialog)
        self.checkBoxMCPX1.setObjectName("checkBoxMCPX1")
        self.verticalLayout.addWidget(self.checkBoxMCPX1)
        self.checkBoxMCPX2 = QtWidgets.QCheckBox(ViewGraphicsDialog)
        self.checkBoxMCPX2.setObjectName("checkBoxMCPX2")
        self.verticalLayout.addWidget(self.checkBoxMCPX2)
        self.checkBoxMCPY1 = QtWidgets.QCheckBox(ViewGraphicsDialog)
        self.checkBoxMCPY1.setObjectName("checkBoxMCPY1")
        self.verticalLayout.addWidget(self.checkBoxMCPY1)
        self.checkBoxMCPY2 = QtWidgets.QCheckBox(ViewGraphicsDialog)
        self.checkBoxMCPY2.setObjectName("checkBoxMCPY2")
        self.verticalLayout.addWidget(self.checkBoxMCPY2)
        self.checkBoxCountDetectors = QtWidgets.QCheckBox(ViewGraphicsDialog)
        self.checkBoxCountDetectors.setObjectName("checkBoxCountDetectors")
        self.verticalLayout.addWidget(self.checkBoxCountDetectors)
        self.checkBoxWaveDetectors = QtWidgets.QCheckBox(ViewGraphicsDialog)
        self.checkBoxWaveDetectors.setObjectName("checkBoxWaveDetectors")
        self.verticalLayout.addWidget(self.checkBoxWaveDetectors)
        self.pushButtonClose = QtWidgets.QPushButton(ViewGraphicsDialog)
        self.pushButtonClose.setObjectName("pushButtonClose")
        self.verticalLayout.addWidget(self.pushButtonClose)

        self.retranslateUi(ViewGraphicsDialog)
        QtCore.QMetaObject.connectSlotsByName(ViewGraphicsDialog)

    def retranslateUi(self, ViewGraphicsDialog):
        _translate = QtCore.QCoreApplication.translate
        ViewGraphicsDialog.setWindowTitle(_translate("ViewGraphicsDialog", "Edit plots"))
        self.checkBoxMCPX1.setText(_translate("ViewGraphicsDialog", "MCP X B1"))
        self.checkBoxMCPX2.setText(_translate("ViewGraphicsDialog", "MCP X B2"))
        self.checkBoxMCPY1.setText(_translate("ViewGraphicsDialog", "MCP Y B1"))
        self.checkBoxMCPY2.setText(_translate("ViewGraphicsDialog", "MCP Y B2"))
        self.checkBoxCountDetectors.setText(_translate("ViewGraphicsDialog", "Count Detectors"))
        self.checkBoxWaveDetectors.setText(_translate("ViewGraphicsDialog", "Wave Detectors"))
        self.pushButtonClose.setText(_translate("ViewGraphicsDialog", "Close"))


class ViewGraphics:
    ui: Ui_ViewGraphicsDialog
    def __init__(self, parent, checkBoxMCPX1Enabled, checkBoxMCPX2Enabled, checkBoxMCPY1Enabled, checkBoxMCPY2Enabled, checkBoxCountDetectorsEnabled, checkBoxWaveDetectorsEnabled):
        self.ui = Ui_ViewGraphicsDialog()
        self.dialog = QtWidgets.QDialog(parent)
        self.ui.setupUi(self.dialog)
        self.ui.checkBoxMCPX1.setChecked(checkBoxMCPX1Enabled)
        self.ui.checkBoxMCPX2.setChecked(checkBoxMCPX2Enabled)
        self.ui.checkBoxMCPY1.setChecked(checkBoxMCPY1Enabled)
        self.ui.checkBoxMCPY2.setChecked(checkBoxMCPY2Enabled)
        self.ui.checkBoxCountDetectors.setChecked(checkBoxCountDetectorsEnabled)
        self.ui.checkBoxWaveDetectors.setChecked(checkBoxWaveDetectorsEnabled)
        self.ui.pushButtonClose.clicked.connect(self.actionClose)
        
    def show(self):
        self.dialog.show()
    def actionClose(self):
        self.dialog.close()
    def getUI(self):
        return self.ui

if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    viewGraphics = ViewGraphics(False,False,True,True,True,True)
    viewGraphics.show()
    sys.exit(app.exec())




'''
Created on Dec 28, 2021

@author: Dmitry
'''

from dataclasses import dataclass
from datetime import datetime as dt
from enum import Enum
from numpy import ndarray


#import array
@dataclass
class DescriptionTICData:

    def __init__(self, dateTime, timeSlice, delay, countChannel, countSlice, threshold):
        self.dateTime = dateTime
        self.timeSlice = timeSlice
        self.delay = delay
        self.countChannel = countChannel
        self.countSlice = countSlice
        self.threshold = threshold

    dateTime: dt
    timeSlice: float
    delay: float
    countChannel: int
    countSlice: int
    threshold: ndarray

@dataclass
class DescriptionDevice:
    name: str
    channelFrom: int
    channelTo: int
    

@dataclass
class RawTICData:
    descriptionTICData: DescriptionTICData
    matrix: ndarray
    
@dataclass
class MeasureProfileTICData:

    def __init__(self, descriptionTICData, countPerSlice, meanPerSlice, sigmaPerSlice, errorSigmaPerSlice, timePerSlice, numberPerChannel, countPerChannel, matrix):
        self.descriptionTICData = descriptionTICData
        self.countPerSlice = countPerSlice
        self.meanPerSlice = meanPerSlice
        self.sigmaPerSlice = sigmaPerSlice
        self.errorSigmaPerSlice = errorSigmaPerSlice
        self.timePerSlice = timePerSlice
        self.numberPerChannel = numberPerChannel
        self.countPerChannel = countPerChannel
        self.matrix = matrix

    descriptionTICData: DescriptionTICData
    countPerSlice: ndarray
    meanPerSlice: ndarray
    sigmaPerSlice: ndarray
    errorSigmaPerSlice: ndarray
    timePerSlice: ndarray
    numberPerChannel: ndarray
    countPerChannel: ndarray
    matrix: ndarray
    
class MeasureProfileTypeEnum(Enum):
    COUNTPERSLICE = (0, "Count per slice", 'Time', "Sec", "Count", "")
    MEANPERSLICE =  (1, "Count average per slice", "Time", "Sec", "Count average", "")
    SIGMAPERSLICE = (2, "Sigma count averge per slice", "Time", "Sec", "Sigma count", "")
    COUNTPERCHANNEL = (3, "Count per channel", "Channel", "", "Count", "")
    MATRIX = (4, "Profile", "Time", "Sec", "Channel", "", "Count", "")
    
    def __init__(self, id, title, nameX, unitX, nameY, unitY, nameColor = "", unitColor = ""):
        self.id = id
        self.title = title
        self.nameX = nameX
        self.unitX = unitX
        self.nameY = nameY
        self.unitY = unitY
        self.nameColor = nameColor
        self.unitColor = unitColor

class MeasureWaveDetectorsEnum(Enum):
    FIRSTSDETECTOR = (0, "Right-Up", 'Time', "Sec", "Count", "")
    SECONDSDETECTOR =  (1, "Right-Bottom", 'Time', "Sec", "Count", "")
    THIRDSDETECTOR = (2, "Left-Bottom", 'Time', "Sec", "Count", "")
    FOURTHSDETECTOR = (3, "Left-Up", 'Time', "Sec", "Count", "")
    FIFTHSDETECTOR = (4, "Center", 'Time', "Sec", "Count", "")
    ALLDETECTOR = (4, "All", 'Time', "Sec", "Count", "")
    
    def __init__(self, id, title, nameX, unitX, nameY, unitY, nameColor = "", unitColor = ""):
        self.id = id
        self.title = title
        self.nameX = nameX
        self.unitX = unitX
        self.nameY = nameY
        self.unitY = unitY
        self.nameColor = nameColor
        self.unitColor = unitColor
    
@dataclass
class MeasureCounterTICData:
    descriptionTICData: DescriptionTICData
    sum: int
    countPerSlice: ndarray
    
    
@dataclass
class DownloadData:
    id:int
    acsn:int
    dateTime:str
    delay:float
    timeslice:float
    threshold: ndarray
    matrix:ndarray


import ConnectionConfigurationDialog
from CountDetectorsWidget import CountScintillators
from OpenSqlData import OpenSQLData
from ProfilePlotWidget import ProfilePlot
from ViewGraphicsDialog import ViewGraphics
from WaveDetectorsWidget import WaveScintillators
from PyQt6 import QtCore, QtGui, QtWidgets
from PyQt6.QtCore import Qt
from PyQt6.QtWidgets import QMenu, QDockWidget, QSplitter


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(800, 600)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.comboBoxType = QtWidgets.QComboBox(self.centralwidget)
        font = QtGui.QFont()
        font.setPointSize(14)
        self.comboBoxType.setFont(font)
        self.comboBoxType.setObjectName("comboBoxType")
        self.horizontalLayout.addWidget(self.comboBoxType)
        self.pushButtonPrev = QtWidgets.QPushButton(self.centralwidget)
        font = QtGui.QFont()
        font.setPointSize(14)
        font.setStyleStrategy(QtGui.QFont.StyleStrategy.PreferDefault)
        self.pushButtonPrev.setFont(font)
        self.pushButtonPrev.setCursor(QtGui.QCursor(QtCore.Qt.CursorShape.ArrowCursor))
        self.pushButtonPrev.setAutoFillBackground(False)
        self.pushButtonPrev.setFlat(False)
        self.pushButtonPrev.setObjectName("pushButtonPrev")
        self.horizontalLayout.addWidget(self.pushButtonPrev)
        self.pushButtonNext = QtWidgets.QPushButton(self.centralwidget)
        font = QtGui.QFont()
        font.setPointSize(14)
        self.pushButtonNext.setFont(font)
        self.pushButtonNext.setObjectName("pushButtonNext")
        self.horizontalLayout.addWidget(self.pushButtonNext)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.horizontalLayoutGraphics = QtWidgets.QHBoxLayout()
        self.horizontalLayoutGraphics.setObjectName("horizontalLayoutGraphics")
        self.verticalLayout.addLayout(self.horizontalLayoutGraphics)
        self.progressBarTask = QtWidgets.QProgressBar(self.centralwidget)
        self.progressBarTask.setProperty("value", 24)
        self.progressBarTask.setObjectName("progressBarTask")
        self.verticalLayout.addWidget(self.progressBarTask)
        self.horizontalLayout_Information = QtWidgets.QHBoxLayout()
        self.horizontalLayout_Information.setObjectName("horizontalLayout_Information")
        self.verticalLayout.addLayout(self.horizontalLayout_Information)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 800, 34))
        font = QtGui.QFont()
        font.setPointSize(16)
        self.menubar.setFont(font)
        self.menubar.setObjectName("menubar")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.menuFile.setFont(font)
        self.menuFile.setObjectName("menuFile")
        self.menuOpen = QtWidgets.QMenu(self.menuFile)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.menuOpen.setFont(font)
        self.menuOpen.setObjectName("menuOpen")
        self.menuExport = QtWidgets.QMenu(self.menuFile)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.menuExport.setFont(font)
        self.menuExport.setObjectName("menuExport")
        self.menuEdit = QtWidgets.QMenu(self.menubar)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.menuEdit.setFont(font)
        self.menuEdit.setObjectName("menuEdit")
        self.menuView = QtWidgets.QMenu(self.menubar)
        self.menuView.setObjectName("menuView")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.actionFrom_sql_database = QtGui.QAction(MainWindow)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.actionFrom_sql_database.setFont(font)
        self.actionFrom_sql_database.setObjectName("actionFrom_sql_database")
        self.actionmeasured_data_to_csv = QtGui.QAction(MainWindow)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.actionmeasured_data_to_csv.setFont(font)
        self.actionmeasured_data_to_csv.setObjectName("actionmeasured_data_to_csv")
        self.actionConnectionSqlDatabase = QtGui.QAction(MainWindow)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.actionConnectionSqlDatabase.setFont(font)
        self.actionConnectionSqlDatabase.setObjectName("actionConnectionSqlDatabase")
        self.actionPlots = QtGui.QAction(MainWindow)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.actionPlots.setFont(font)
        self.actionPlots.setObjectName("actionPlots")
        self.menuOpen.addAction(self.actionFrom_sql_database)
        self.menuExport.addAction(self.actionmeasured_data_to_csv)
        self.menuFile.addAction(self.menuOpen.menuAction())
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.menuExport.menuAction())
        self.menuEdit.addAction(self.actionConnectionSqlDatabase)
        self.menuView.addAction(self.actionPlots)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuEdit.menuAction())
        self.menubar.addAction(self.menuView.menuAction())

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.pushButtonPrev.setText(_translate("MainWindow", "Prev"))
        self.pushButtonNext.setText(_translate("MainWindow", "Next"))
        self.menuFile.setTitle(_translate("MainWindow", "File"))
        self.menuOpen.setTitle(_translate("MainWindow", "Open.."))
        self.menuExport.setTitle(_translate("MainWindow", "Export.."))
        self.menuEdit.setTitle(_translate("MainWindow", "Edit"))
        self.menuView.setTitle(_translate("MainWindow", "View"))
        self.actionFrom_sql_database.setText(_translate("MainWindow", "From sql database"))
        self.actionmeasured_data_to_csv.setText(_translate("MainWindow", "measured data to csv"))
        self.actionConnectionSqlDatabase.setText(_translate("MainWindow", "Connection to sql database"))
        self.actionPlots.setText(_translate("MainWindow", "Plots"))


class MainWindow():
    def __init__(self):
        self.ui = Ui_MainWindow()
        self.MainWindow = QtWidgets.QMainWindow()
        self.ui.setupUi(self.MainWindow)
        self.ui.actionConnectionSqlDatabase.triggered.connect(self.openConnectionConfiguration)
        self.ui.actionPlots.triggered.connect(self.openViewGraphics)
        self.ui.actionFrom_sql_database.triggered.connect(self.openSQLData)
        
        
        self.profilePlotMCPX1 = ProfilePlot("MCP X 1")
        self.addWidgetToCentralLayout(self.profilePlotMCPX1.getWidget())
        self.profilePlotMCPX2 = ProfilePlot("MCP X 2")
        self.addWidgetToCentralLayout(self.profilePlotMCPX2.getWidget())
        self.profilePlotMCPY1 = ProfilePlot("MCP Y 1")
        self.addWidgetToCentralLayout(self.profilePlotMCPY1.getWidget())
        self.profilePlotMCPY2 = ProfilePlot("MCP Y 2")
        self.addWidgetToCentralLayout(self.profilePlotMCPY2.getWidget())
        self.waveDetectors = WaveScintillators("Galo Beam")
        self.addWidgetToCentralLayout(self.waveDetectors.getWidget())
        self.countDetectors = CountScintillators()
        self.addWidgetToCentralLayout(self.countDetectors.getWidget())
    
    def openConnectionConfiguration(self):
        connectionConfigurationDialog = ConnectionConfigurationDialog.ConnectionConfiguration(lambda self, answer, result: self.setNewConnectionconfiguration(result) if(answer) else None)
        connectionConfigurationDialog.show()
    def setNewConnectionConfiguration(self, configuration):
        self.sqlConfiguration = configuration 
    def openViewGraphics(self):
        self.viewGraphics = ViewGraphics(self.ui.centralwidget , not self.profilePlotMCPX1.getWidget().isHidden(), not self.profilePlotMCPX2.getWidget().isHidden(), not self.profilePlotMCPY1.getWidget().isHidden(),not self.profilePlotMCPY2.getWidget().isHidden(), not self.waveDetectors.getWidget().isHidden(), not self.countDetectors.getWidget().isHidden())
        self.viewGraphics.getUI().checkBoxMCPX1.stateChanged.connect(lambda state: self.setHideWidget(self.profilePlotMCPX1.getWidget(),not state))
        self.viewGraphics.getUI().checkBoxMCPX2.stateChanged.connect(lambda state: self.setHideWidget(self.profilePlotMCPX2.getWidget(),not state))
        self.viewGraphics.getUI().checkBoxMCPY1.stateChanged.connect(lambda state: self.setHideWidget(self.profilePlotMCPY1.getWidget(),not state))
        self.viewGraphics.getUI().checkBoxMCPY2.stateChanged.connect(lambda state: self.setHideWidget(self.profilePlotMCPY2.getWidget(),not state))
        self.viewGraphics.getUI().checkBoxWaveDetectors.stateChanged.connect(lambda state: self.setHideWidget(self.waveDetectors.getWidget(),not state))
        self.viewGraphics.getUI().checkBoxCountDetectors.stateChanged.connect(lambda state: self.setHideWidget(self.countDetectors.getWidget(),not state))
        self.viewGraphics.show()
    def openSQLData(self):
        self.openSQLData = OpenSQLData()
        self.openSQLData.show()
    def addWidgetToCentralLayout(self, widget):
        i = 5
        #self.ui.splitter.addWidget(widget)
    def addDockWidgetToCentralLayout(self, widget):
        window = self.ui.mdiAreaGraphics.addSubWindow(widget)
        window.setWindowTitle("JHi")
        self.ui.mdiAreaGraphics.tileSubWindows()
    def show(self):
        self.MainWindow.show()
    def setHideWidget(self, widget, state):
        widget.setHidden(state)
        
if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    MainWindow = MainWindow()
    MainWindow.show()
    sys.exit(app.exec())
    
    
    



'''
Created on Dec 28, 2021

@author: Dmitry
'''

from PyQt6 import QtCore, QtGui, QtWidgets
from PyQt6.QtCore import QObject, pyqtSignal, pyqtSlot 
from PyQt6.QtWidgets import QSizePolicy, QLabel
import DataTIC
from datetime import datetime as dt
from numpy import ndarray
import numpy as np
import pyqtgraph as pg
from re import match


class Ui_Plot(QObject):
    
    deleteWidgetIsCall = pyqtSignal()
    title:str
    flagDataSet:bool
    
    def __init__(self):
        QObject.__init__(self)
        self.flagDataSet = False
        
    
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(400, 300)
        Form.setWindowOpacity(0)
        Form.setContentsMargins(0, 0, 0, 0)
        #self.horizontalLayout = QtWidgets.QHBoxLayout(Form)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setSizeConstraint(QtWidgets.QLayout.SizeConstraint.SetDefaultConstraint)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.horizontalLayout.addLayout(self.verticalLayout)
        self.comboBoxTypePlot = QtWidgets.QComboBox(Form)
        self.comboBoxTypePlot.setObjectName("comboBoxTypePlot")
        self.comboBoxTypePlot.currentIndexChanged.connect(self.onComboBoxTypePlotIndexChanged)
        
        '''for item in DataTIC.MeasureProfileTypeEnum:
            self.comboBoxTypePlot.addItem(item.title)'''
        
        self.horizontalLayout.addWidget(self.comboBoxTypePlot)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.titleLabel = QLabel(Form)
        self.horizontalLayout.addWidget(self.titleLabel)
        self.horizontalLayout.addItem(spacerItem)
        #self.pushButtonDelete = QtWidgets.QPushButton(Form)
        #sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Fixed)
        #sizePolicy.setHorizontalStretch(25)
        #sizePolicy.setVerticalStretch(25)
        #sizePolicy.setHeightForWidth(self.pushButtonDelete.sizePolicy().hasHeightForWidth())
        #self.pushButtonDelete.setSizePolicy(sizePolicy)
        #self.pushButtonDelete.setMinimumSize(QtCore.QSize(25, 25))
        #self.pushButtonDelete.setMaximumSize(QtCore.QSize(25, 25))
        #self.pushButtonDelete.setSizeIncrement(QtCore.QSize(0, 0))
        #self.pushButtonDelete.setObjectName("pushButtonDelete")
        #self.pushButtonDelete.clicked.connect(self.deletePlot)
        #self.horizontalLayout.addWidget(self.pushButtonDelete)
        self.verticalLayout.addLayout(self.horizontalLayout)
        
        self.layoutPlot = pg.GraphicsLayoutWidget()
        self.linePlot = self.layoutPlot.addPlot()
        self.colorMapPlot = self.layoutPlot.addPlot()
        self.linePlot.hide()
        self.colorMapPlot.hide()
        self.cmap = pg.colormap.get('CET-L9')
        self.bar = pg.ColorBarItem(
            interactive=True, colorMap=self.cmap)
        font=QtGui.QFont()
        font.setPixelSize(20)
        self.linePlot.getAxis("bottom").setTickFont(font)
        self.linePlot.getAxis("left").setTickFont(font)
        self.colorMapPlot.getAxis("bottom").setTickFont(font)
        self.colorMapPlot.getAxis("left").setTickFont(font)
        self.bar.getAxis("right").setTickFont(font)

        #data = np.fromfunction(lambda i, j: i*j, (100, 100))
        self.image = pg.ImageItem()
        self.colorMapPlot.addItem(self.image)
        self.bar.setImageItem(self.image, insert_in=self.colorMapPlot)
        
        self.verticalLayout.addWidget(self.layoutPlot)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)
        
        self.labelAxisStyle = {'color': '#FFF', 'font-size': '14pt'}
        self.titlePlotStyle = {'color': '#FFF', 'font-size': '20pt'}

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        #self.pushButtonDelete.setText(_translate("Form", "X"))
    def setMainTitle(self, text):
        self.titleLabel.setText(text)
        
    def plotLineBy2darray(self, data, titlePlot, titleX, unitX, titleY, unitY):
        splittedData = np.hsplit(data, 2)
        self.plotLineByXY(
            splittedData[0].flatten(), 
            splittedData[1].flatten(), 
            titlePlot, 
            titleX, unitX, 
            titleY, unitY)
    def plotLineByXY(self, x, y, titlePlot, titleX, unitX, titleY, unitY):
        self.colorMapPlot.hide()
        self.linePlot.show()
        self.linePlot.clear()
        self.linePlot.plot(x=x, y=y)
        self.linePlot.setTitle(titlePlot, **self.titlePlotStyle)
        self.linePlot.setLabel('left', titleY, units=unitY, **self.labelAxisStyle)
        self.linePlot.setLabel('bottom', titleX, units=unitX, **self.labelAxisStyle)
        
    def plotColorMap(self, data, titlePlot, titleX, unitX, titleY, unitY, titleColorBar, unitColor):
        self.colorMapPlot.show()
        self.linePlot.hide()
        self.image.setImage(image=data)
        self.bar._update_items()
        self.colorMapPlot.setTitle(titlePlot, **self.titlePlotStyle)
        self.colorMapPlot.setLabel('left', titleY, units=unitY, **self.labelAxisStyle)
        self.colorMapPlot.setLabel('bottom', titleX, units=unitX, **self.labelAxisStyle)
        self.bar.setLabel('left', titleColorBar, units=unitColor, **self.labelAxisStyle)
        
    def setBlockData(self, data):
        self.blockData = data
        self.flagDataSet = True
    def getBlockData(self):
        return self.blockData
    
    def deletePlot(self):
        #self.deleteWidgetIsCall.emit()
        
        print("widgethide")
        
    def onComboBoxTypePlotIndexChanged(self, index): 0
    
    def addItemcomboBoxTypePlot(self, item):
        self.comboBoxTypePlot.addItem(item)

if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    #Form.setSizePolicy(QSizePolicy.PolicyFlag.ExpandFlag,QSizePolicy.PolicyFlag.ExpandFlag)
    ui = Ui_Plot()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec())



from PyQt6 import QtCore, QtGui, QtWidgets
from PyQt6.QtCore import QObject
import Plot, DataTIC


class ProfilePlot(Plot.Ui_Plot):
    def __init__(self, title):
        super().__init__()
        self.form = QtWidgets.QWidget()
        super().setupUi(self.form)
        for item in DataTIC.MeasureProfileTypeEnum:
            self.addItemcomboBoxTypePlot(item.title)
        super().setMainTitle(title)
            
    def onComboBoxTypePlotIndexChanged(self, index):
        if not self.flagDataSet: return
        match index:
            case 0:
                self.plotLineByXY(
                    self.getBlockData().countPerSlice, 
                    self.getBlockData().timePerSlice, 
                    DataTIC.MeasureProfileTypeEnum[0].title, 
                    DataTIC.MeasureProfileTypeEnum[0].nameX, 
                    DataTIC.MeasureProfileTypeEnum[0].unitX, 
                    DataTIC.MeasureProfileTypeEnum[0].nameY, 
                    DataTIC.MeasureProfileTypeEnum[0].unitY)
            case 1:
                self.plotLineByXY(
                    self.getBlockData().meanPerSlice, 
                    self.getBlockData().timePerSlice, 
                    DataTIC.MeasureProfileTypeEnum[1].title, 
                    DataTIC.MeasureProfileTypeEnum[1].nameX, 
                    DataTIC.MeasureProfileTypeEnum[1].unitX, 
                    DataTIC.MeasureProfileTypeEnum[1].nameY, 
                    DataTIC.MeasureProfileTypeEnum[1].unitY)
            case 2:
                self.plotLineByXY(
                    self.getBlockData().sigmaPerSlice, 
                    self.getBlockData().timePerSlice, 
                    DataTIC.MeasureProfileTypeEnum[2].title, 
                    DataTIC.MeasureProfileTypeEnum[2].nameX, 
                    DataTIC.MeasureProfileTypeEnum[2].unitX, 
                    DataTIC.MeasureProfileTypeEnum[2].nameY, 
                    DataTIC.MeasureProfileTypeEnum[2].unitY)
            case 3:
                self.plotLineByXY(
                    self.getBlockData().countPerChannel, 
                    self.getBlockData().numberPerChannel, 
                    DataTIC.MeasureProfileTypeEnum[3].title, 
                    DataTIC.MeasureProfileTypeEnum[3].nameX, 
                    DataTIC.MeasureProfileTypeEnum[3].unitX, 
                    DataTIC.MeasureProfileTypeEnum[3].nameY, 
                    DataTIC.MeasureProfileTypeEnum[3].unitY)
            case 4:
                self.plotColorMap(
                    self.getBlockData().matrix,
                    DataTIC.MeasureProfileTypeEnum[3].title, 
                    DataTIC.MeasureProfileTypeEnum[3].nameX, 
                    DataTIC.MeasureProfileTypeEnum[3].unitX, 
                    DataTIC.MeasureProfileTypeEnum[3].nameY, 
                    DataTIC.MeasureProfileTypeEnum[3].unitY,
                    DataTIC.MeasureProfileTypeEnum[3].nameColor,
                    DataTIC.MeasureProfileTypeEnum[3].unitColor)
        print(index)
        
    def getWidget(self):
        return self.form
        
if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = ProfilePlot()
    Form.show()
    sys.exit(app.exec())  

'''
from PyQt6 import QtCore, QtGui, QtWidgets
from PyQt6.QtCore import QObject, pyqtSignal, pyqtSlot 
import numpy as np
import pyqtgraph as pg
from numpy import ndarray
from TICSummary import DataTIC
from datetime import datetime as dt
from re import match

class Ui_Plot(QObject):
    
    def __init__(self):
        QObject.__init__(self)
    
    deleteWidgetIsCall = pyqtSignal()
    
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(400, 300)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setSizeConstraint(QtWidgets.QLayout.SizeConstraint.SetDefaultConstraint)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.comboBoxTypePlot = QtWidgets.QComboBox(Form)
        self.comboBoxTypePlot.setObjectName("comboBoxTypePlot")
        self.comboBoxTypePlot.currentIndexChanged.connect(self.onComboBoxTypePlotIndexChanged)
        
        for item in DataTIC.MeasureProfileTypeEnum:
            self.comboBoxTypePlot.addItem(item.title)
        
        self.horizontalLayout.addWidget(self.comboBoxTypePlot)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.pushButtonDelete = QtWidgets.QPushButton(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(25)
        sizePolicy.setVerticalStretch(25)
        sizePolicy.setHeightForWidth(self.pushButtonDelete.sizePolicy().hasHeightForWidth())
        self.pushButtonDelete.setSizePolicy(sizePolicy)
        self.pushButtonDelete.setMinimumSize(QtCore.QSize(25, 25))
        self.pushButtonDelete.setMaximumSize(QtCore.QSize(25, 25))
        self.pushButtonDelete.setSizeIncrement(QtCore.QSize(0, 0))
        self.pushButtonDelete.setObjectName("pushButtonDelete")
        self.pushButtonDelete.clicked.connect(self.deletePlot)
        self.horizontalLayout.addWidget(self.pushButtonDelete)
        self.verticalLayout.addLayout(self.horizontalLayout)
        
        self.layoutPlot = pg.GraphicsLayoutWidget()
        self.linePlot = self.layoutPlot.addPlot()
        self.colorMapPlot = self.layoutPlot.addPlot()
        self.linePlot.hide()
        self.colorMapPlot.hide()
        self.cmap = pg.colormap.get('CET-L9')
        self.bar = pg.ColorBarItem(
            interactive=True, colorMap=self.cmap)
        font=QtGui.QFont()
        font.setPixelSize(20)
        self.linePlot.getAxis("bottom").setTickFont(font)
        self.linePlot.getAxis("left").setTickFont(font)
        self.colorMapPlot.getAxis("bottom").setTickFont(font)
        self.colorMapPlot.getAxis("left").setTickFont(font)
        self.bar.getAxis("right").setTickFont(font)

        #data = np.fromfunction(lambda i, j: i*j, (100, 100))
        self.image = pg.ImageItem()
        self.colorMapPlot.addItem(self.image)
        self.bar.setImageItem(self.image, insert_in=self.colorMapPlot)
        
        self.verticalLayout.addWidget(self.layoutPlot)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)
        
        self.labelAxisStyle = {'color': '#FFF', 'font-size': '14pt'}
        self.titlePlotStyle = {'color': '#FFF', 'font-size': '20pt'}

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.pushButtonDelete.setText(_translate("Form", "X"))
        
    def plotLineBy2darray(self, data, titlePlot, titleX, unitX, titleY, unitY):
        splittedData = np.hsplit(data, 2)
        self.plotLineByXY(
            splittedData[0].flatten(), 
            splittedData[1].flatten(), 
            titlePlot, 
            titleX, unitX, 
            titleY, unitY)
    def plotLineByXY(self, x, y, titlePlot, titleX, unitX, titleY, unitY):
        self.colorMapPlot.hide()
        self.linePlot.show()
        self.linePlot.clear()
        self.linePlot.plot(x=x, y=y)
        self.linePlot.setTitle(titlePlot, **self.titlePlotStyle)
        self.linePlot.setLabel('left', titleY, units=unitY, **self.labelAxisStyle)
        self.linePlot.setLabel('bottom', titleX, units=unitX, **self.labelAxisStyle)
        
    def plotColorMap(self, data, titlePlot, titleX, unitX, titleY, unitY, titleColorBar, unitColor):
        self.colorMapPlot.show()
        self.linePlot.hide()
        self.image.setImage(image=data)
        self.bar._update_items()
        self.colorMapPlot.setTitle(titlePlot, **self.titlePlotStyle)
        self.colorMapPlot.setLabel('left', titleY, units=unitY, **self.labelAxisStyle)
        self.colorMapPlot.setLabel('bottom', titleX, units=unitX, **self.labelAxisStyle)
        self.bar.setLabel('left', titleColorBar, units=unitColor, **self.labelAxisStyle)
        
    def setBlockData(self, data):
        self.blockData = data
        
    def deletePlot(self):
        self.deleteWidgetIsCall.emit()
    def onComboBoxTypePlotIndexChanged(self, index):
        match index:
            case 0:
                self.plotLineByXY(
                    self.blockData.countPerSlice, 
                    self.blockData.timePerSlice, 
                    DataTIC.MeasureProfileTypeEnum[0].title, 
                    DataTIC.MeasureProfileTypeEnum[0].nameX, 
                    DataTIC.MeasureProfileTypeEnum[0].unitX, 
                    DataTIC.MeasureProfileTypeEnum[0].nameY, 
                    DataTIC.MeasureProfileTypeEnum[0].unitY)
            case 1:
                self.plotLineByXY(
                    self.blockData.meanPerSlice, 
                    self.blockData.timePerSlice, 
                    DataTIC.MeasureProfileTypeEnum[1].title, 
                    DataTIC.MeasureProfileTypeEnum[1].nameX, 
                    DataTIC.MeasureProfileTypeEnum[1].unitX, 
                    DataTIC.MeasureProfileTypeEnum[1].nameY, 
                    DataTIC.MeasureProfileTypeEnum[1].unitY)
            case 2:
                self.plotLineByXY(
                    self.blockData.sigmaPerSlice, 
                    self.blockData.timePerSlice, 
                    DataTIC.MeasureProfileTypeEnum[2].title, 
                    DataTIC.MeasureProfileTypeEnum[2].nameX, 
                    DataTIC.MeasureProfileTypeEnum[2].unitX, 
                    DataTIC.MeasureProfileTypeEnum[2].nameY, 
                    DataTIC.MeasureProfileTypeEnum[2].unitY)
            case 3:
                self.plotLineByXY(
                    self.blockData.countPerChannel, 
                    self.blockData.numberPerChannel, 
                    DataTIC.MeasureProfileTypeEnum[3].title, 
                    DataTIC.MeasureProfileTypeEnum[3].nameX, 
                    DataTIC.MeasureProfileTypeEnum[3].unitX, 
                    DataTIC.MeasureProfileTypeEnum[3].nameY, 
                    DataTIC.MeasureProfileTypeEnum[3].unitY)
            case 4:
                self.plotColorMap(
                    self.blockData.matrix,
                    DataTIC.MeasureProfileTypeEnum[3].title, 
                    DataTIC.MeasureProfileTypeEnum[3].nameX, 
                    DataTIC.MeasureProfileTypeEnum[3].unitX, 
                    DataTIC.MeasureProfileTypeEnum[3].nameY, 
                    DataTIC.MeasureProfileTypeEnum[3].unitY,
                    DataTIC.MeasureProfileTypeEnum[3].nameColor,
                    DataTIC.MeasureProfileTypeEnum[3].unitColor)
        print(index)
        
if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Plot()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec())
'''


from PyQt6 import QtCore, QtGui, QtWidgets   
import MainWindow, ConnectionConfigurationDialog, DatabaseMYSQL, Plot

class EntryPoint:
    sqlParameters:DatabaseMYSQL.ParameterConnection
    profilePlot1: Plot
    
    def run(self):
        import sys
        app = QtWidgets.QApplication(sys.argv)
        self.mainWindow = MainWindow.MainWindow()
        
        self.mainWindow.show()
        sys.exit(app.exec())
    
    
if __name__ == '__main__':
    entryPoint = EntryPoint()
    entryPoint.run()


# Form implementation generated from reading ui file 'CountScintillators.ui'
#
# Created by: PyQt6 UI code generator 6.2.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_CountScintillatorsWidget(object):
    def setupUi(self, CountScintillatorsWidget):
        CountScintillatorsWidget.setObjectName("CountScintillators")
        CountScintillatorsWidget.resize(400, 300)
        CountScintillatorsWidget.setWindowTitle("")
        self.gridLayout = QtWidgets.QGridLayout(CountScintillatorsWidget)
        self.gridLayout.setObjectName("gridLayout")
        self.spinBoxCountLeftUp = QtWidgets.QSpinBox(CountScintillatorsWidget)
        font = QtGui.QFont()
        font.setPointSize(14)
        self.spinBoxCountLeftUp.setFont(font)
        self.spinBoxCountLeftUp.setReadOnly(True)
        self.spinBoxCountLeftUp.setButtonSymbols(QtWidgets.QAbstractSpinBox.ButtonSymbols.NoButtons)
        self.spinBoxCountLeftUp.setObjectName("spinBoxCountLeftUp")
        self.gridLayout.addWidget(self.spinBoxCountLeftUp, 0, 0, 1, 1)
        self.spinBoxCountRightUp = QtWidgets.QSpinBox(CountScintillatorsWidget)
        font = QtGui.QFont()
        font.setPointSize(14)
        self.spinBoxCountRightUp.setFont(font)
        self.spinBoxCountRightUp.setReadOnly(True)
        self.spinBoxCountRightUp.setButtonSymbols(QtWidgets.QAbstractSpinBox.ButtonSymbols.NoButtons)
        self.spinBoxCountRightUp.setObjectName("spinBoxCountRightUp")
        self.gridLayout.addWidget(self.spinBoxCountRightUp, 0, 2, 1, 1)
        self.spinBoxCountCenter = QtWidgets.QSpinBox(CountScintillatorsWidget)
        font = QtGui.QFont()
        font.setPointSize(14)
        self.spinBoxCountCenter.setFont(font)
        self.spinBoxCountCenter.setReadOnly(True)
        self.spinBoxCountCenter.setButtonSymbols(QtWidgets.QAbstractSpinBox.ButtonSymbols.NoButtons)
        self.spinBoxCountCenter.setObjectName("spinBoxCountCenter")
        self.gridLayout.addWidget(self.spinBoxCountCenter, 1, 1, 1, 1)
        self.spinBoxCountLeftBottom = QtWidgets.QSpinBox(CountScintillatorsWidget)
        font = QtGui.QFont()
        font.setPointSize(14)
        self.spinBoxCountLeftBottom.setFont(font)
        self.spinBoxCountLeftBottom.setReadOnly(True)
        self.spinBoxCountLeftBottom.setButtonSymbols(QtWidgets.QAbstractSpinBox.ButtonSymbols.NoButtons)
        self.spinBoxCountLeftBottom.setObjectName("spinBoxCountLeftBottom")
        self.gridLayout.addWidget(self.spinBoxCountLeftBottom, 2, 0, 1, 1)
        self.spinBoxRightBottom = QtWidgets.QSpinBox(CountScintillatorsWidget)
        font = QtGui.QFont()
        font.setPointSize(14)
        self.spinBoxRightBottom.setFont(font)
        self.spinBoxRightBottom.setReadOnly(True)
        self.spinBoxRightBottom.setButtonSymbols(QtWidgets.QAbstractSpinBox.ButtonSymbols.NoButtons)
        self.spinBoxRightBottom.setObjectName("spinBoxRightBottom")
        self.gridLayout.addWidget(self.spinBoxRightBottom, 2, 2, 1, 1)

        self.retranslateUi(CountScintillatorsWidget)
        QtCore.QMetaObject.connectSlotsByName(CountScintillatorsWidget)

    def retranslateUi(self, CountScintillatorsWidget):
        pass

class CountScintillators():
    def __init__(self):
        self.widget = QtWidgets.QWidget()
        self.ui = Ui_CountScintillatorsWidget()
        self.ui.setupUi(self.widget)
    def show(self):
        self.widget.show()
    def getWidget(self):
        return self.widget

if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    countScintillatorsWidget = CountScintillators()
    countScintillatorsWidget.show()
    sys.exit(app.exec())



from PyQt6 import QtCore, QtGui, QtWidgets
from PyQt6.QtWidgets import QMessageBox


class Ui_OpenSQLDataDialog(object):
    def setupUi(self, OpenSQLDataDialog):
        OpenSQLDataDialog.setObjectName("OpenSQLDataDialog")
        OpenSQLDataDialog.resize(701, 600)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(OpenSQLDataDialog)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.radioButtonSeveral = QtWidgets.QRadioButton(OpenSQLDataDialog)
        self.radioButtonSeveral.setChecked(True)
        self.radioButtonSeveral.setObjectName("radioButtonSeveral")
        self.verticalLayout.addWidget(self.radioButtonSeveral)
        self.radioButtonFromFirst = QtWidgets.QRadioButton(OpenSQLDataDialog)
        self.radioButtonFromFirst.setObjectName("radioButtonFromFirst")
        self.verticalLayout.addWidget(self.radioButtonFromFirst)
        self.horizontalLayout_2.addLayout(self.verticalLayout)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.verticalLayout_2.addLayout(self.horizontalLayout_2)
        self.tableViewData = QtWidgets.QTableView(OpenSQLDataDialog)
        self.tableViewData.setObjectName("tableViewData")
        self.verticalLayout_2.addWidget(self.tableViewData)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout.addItem(spacerItem1)
        self.pushButtonOpen = QtWidgets.QPushButton(OpenSQLDataDialog)
        self.pushButtonOpen.setObjectName("pushButtonOpen")
        self.horizontalLayout.addWidget(self.pushButtonOpen)
        self.verticalLayout_2.addLayout(self.horizontalLayout)

        self.retranslateUi(OpenSQLDataDialog)
        QtCore.QMetaObject.connectSlotsByName(OpenSQLDataDialog)

    def retranslateUi(self, OpenSQLDataDialog):
        _translate = QtCore.QCoreApplication.translate
        OpenSQLDataDialog.setWindowTitle(_translate("OpenSQLDataDialog", "Open data"))
        self.radioButtonSeveral.setText(_translate("OpenSQLDataDialog", "Selection of several data"))
        self.radioButtonFromFirst.setText(_translate("OpenSQLDataDialog", "Selection of several from the first"))
        self.pushButtonOpen.setText(_translate("OpenSQLDataDialog", "Open"))



class OpenSQLData():
    def __init__(self, model, funcCallback):
        self.dialog = QtWidgets.QDialog()
        self.ui = Ui_OpenSQLDataDialog()
        self.ui.setupUi(self.dialog)
        self.model = model
        
        self.ui.tableViewData.setModel(self.model)
        self.ui.tableViewData.setSelectionModel(QtWidgets.QAbstractItemView.SelectionMode.ContiguousSelection)
        
        self.ui.radioButtonSeveral.toggled.connect(self.radioButtonSeveralToggled)
        self.ui.radioButtonFromFirst.toggled.connect(self.radioButtonFromFirstToggled)
        self.ui.pushButtonOpen.clicked.connect(self.pushButtonOpenClicked)
        self.funcCallBack = funcCallback
    def show(self):
        self.dialog.show()
    
    def radioButtonSeveralToggled(self, checked:bool):
        if checked:
            self.ui.tableViewData.setSelectionModel(QtWidgets.QAbstractItemView.SelectionMode.ContiguousSelection)
            self.ui.tableViewData.clearSelection()
    def radioButtonFromFirstToggled(self, checked:bool):
        if checked:
            self.ui.tableViewData.setSelectionModel(QtWidgets.QAbstractItemView.SelectionMode.SingleSelection)
            self.ui.tableViewData.clearSelection()
    def pushButtonOpenClicked(self):
        list = self.ui.tableViewData.selectionModel().selectedRows()
        
        if list.count() <= 0:
            msqBox = QMessageBox()
            msqBox.setText("No data selected. \nPlease select data")
            msqBox.exec()
            return;
        if self.ui.radioButtonSeveral.isChecked():
            self.selectedRow = list
        if self.ui.radioButtonFromFirst.isChecked():
            for i in range(list[0]+1, self.ui.tableViewData.model().rowCount()):
                list.append(i)
            self.selectedRow = list
            self.funcCallBack(list)
        
        
    


from PyQt6 import QtCore, QtGui, QtWidgets
from PyQt6.QtCore import QObject
import Plot, DataTIC


class WaveScintillators(Plot.Ui_Plot):
    def __init__(self, title):
        super().__init__()
        self.form = QtWidgets.QWidget()
        super().setupUi(self.form)
        for item in DataTIC.MeasureWaveDetectorsEnum:
            self.addItemcomboBoxTypePlot(item.title)
        super().setMainTitle(title)
    def getWidget(self):
        return self.form


from PyQt6 import QtCore, QtGui, QtWidgets
from PyQt6.QtCore import QObject, pyqtSignal, pyqtSlot 
from PyQt6.QtWidgets import QFileDialog, QMessageBox
import DatabaseMYSQL
import json
import os
from pathlib import Path


class Ui_ConnectionConfigurationDialog(object):
    def setupUi(self, ConnectionConfigurationDialog):
        ConnectionConfigurationDialog.setObjectName("ConnectionConfigurationDialog")
        ConnectionConfigurationDialog.setWindowModality(QtCore.Qt.WindowModality.ApplicationModal)
        ConnectionConfigurationDialog.resize(488, 300)
        ConnectionConfigurationDialog.setModal(True)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(ConnectionConfigurationDialog)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.label = QtWidgets.QLabel(ConnectionConfigurationDialog)
        self.label.setObjectName("label")
        self.verticalLayout_2.addWidget(self.label)
        self.label_2 = QtWidgets.QLabel(ConnectionConfigurationDialog)
        self.label_2.setObjectName("label_2")
        self.verticalLayout_2.addWidget(self.label_2)
        self.label_3 = QtWidgets.QLabel(ConnectionConfigurationDialog)
        self.label_3.setObjectName("label_3")
        self.verticalLayout_2.addWidget(self.label_3)
        self.label_4 = QtWidgets.QLabel(ConnectionConfigurationDialog)
        self.label_4.setObjectName("label_4")
        self.verticalLayout_2.addWidget(self.label_4)
        self.label_5 = QtWidgets.QLabel(ConnectionConfigurationDialog)
        self.label_5.setObjectName("label_5")
        self.verticalLayout_2.addWidget(self.label_5)
        self.label_6 = QtWidgets.QLabel(ConnectionConfigurationDialog)
        self.label_6.setObjectName("label_6")
        self.verticalLayout_2.addWidget(self.label_6)
        self.horizontalLayout_3.addLayout(self.verticalLayout_2)
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.lineEditHost = QtWidgets.QLineEdit(ConnectionConfigurationDialog)
        self.lineEditHost.setObjectName("lineEditHost")
        self.verticalLayout.addWidget(self.lineEditHost)
        self.lineEditDB = QtWidgets.QLineEdit(ConnectionConfigurationDialog)
        self.lineEditDB.setObjectName("lineEditDB")
        self.verticalLayout.addWidget(self.lineEditDB)
        self.spinBoxPort = QtWidgets.QSpinBox(ConnectionConfigurationDialog)
        self.spinBoxPort.setButtonSymbols(QtWidgets.QAbstractSpinBox.ButtonSymbols.NoButtons)
        self.spinBoxPort.setMaximum(9999)
        self.spinBoxPort.setObjectName("spinBoxPort")
        self.verticalLayout.addWidget(self.spinBoxPort)
        self.lineEditUser = QtWidgets.QLineEdit(ConnectionConfigurationDialog)
        self.lineEditUser.setObjectName("lineEditUser")
        self.verticalLayout.addWidget(self.lineEditUser)
        self.lineEditPassword = QtWidgets.QLineEdit(ConnectionConfigurationDialog)
        self.lineEditPassword.setObjectName("lineEditPassword")
        self.verticalLayout.addWidget(self.lineEditPassword)
        self.lineEditTable = QtWidgets.QLineEdit(ConnectionConfigurationDialog)
        self.lineEditTable.setObjectName("lineEditTable")
        self.verticalLayout.addWidget(self.lineEditTable)
        self.horizontalLayout_3.addLayout(self.verticalLayout)
        self.verticalLayout_3.addLayout(self.horizontalLayout_3)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.pushButtonWriteConf = QtWidgets.QPushButton(ConnectionConfigurationDialog)
        self.pushButtonWriteConf.setObjectName("pushButtonWriteConf")
        self.horizontalLayout.addWidget(self.pushButtonWriteConf)
        self.pushButtonReadConf = QtWidgets.QPushButton(ConnectionConfigurationDialog)
        self.pushButtonReadConf.setObjectName("pushButtonReadConf")
        self.horizontalLayout.addWidget(self.pushButtonReadConf)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.verticalLayout_3.addLayout(self.horizontalLayout)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem1)
        self.pushButtonSave = QtWidgets.QPushButton(ConnectionConfigurationDialog)
        self.pushButtonSave.setObjectName("pushButtonSave")
        self.horizontalLayout_2.addWidget(self.pushButtonSave)
        self.pushButtonCancel = QtWidgets.QPushButton(ConnectionConfigurationDialog)
        self.pushButtonCancel.setObjectName("pushButtonCancel")
        self.horizontalLayout_2.addWidget(self.pushButtonCancel)
        self.verticalLayout_3.addLayout(self.horizontalLayout_2)

        self.retranslateUi(ConnectionConfigurationDialog)
        QtCore.QMetaObject.connectSlotsByName(ConnectionConfigurationDialog)

    def retranslateUi(self, ConnectionConfigurationDialog):
        _translate = QtCore.QCoreApplication.translate
        ConnectionConfigurationDialog.setWindowTitle(_translate("ConnectionConfigurationDialog", "Connection configuration"))
        self.label.setText(_translate("ConnectionConfigurationDialog", "Host"))
        self.label_2.setText(_translate("ConnectionConfigurationDialog", "Database"))
        self.label_3.setText(_translate("ConnectionConfigurationDialog", "Port"))
        self.label_4.setText(_translate("ConnectionConfigurationDialog", "User"))
        self.label_5.setText(_translate("ConnectionConfigurationDialog", "Password"))
        self.label_6.setText(_translate("ConnectionConfigurationDialog", "Table"))
        self.pushButtonWriteConf.setText(_translate("ConnectionConfigurationDialog", "Write configuration"))
        self.pushButtonReadConf.setText(_translate("ConnectionConfigurationDialog", "Read configuration"))
        self.pushButtonSave.setText(_translate("ConnectionConfigurationDialog", "Save"))
        self.pushButtonCancel.setText(_translate("ConnectionConfigurationDialog", "Cancel"))


        
class ConnectionConfiguration:
    flagParametersReady:bool
    def __init__(self, funCallBack):
        self.ui = Ui_ConnectionConfigurationDialog()
        self.dialog = QtWidgets.QDialog()
        self.ui.setupUi(self.dialog)
        self.ui.pushButtonReadConf.clicked.connect(self.readConfiguration)
        self.ui.pushButtonWriteConf.clicked.connect(self.writeConfiguration)
        self.ui.pushButtonCancel.clicked.connect(self.cancel)
        self.ui.pushButtonSave.clicked.connect(self.save)
        #self.ui.pushButtonCheck.clicked.connect(self.checkConnection)
        
    def readConfiguration(self):
        fname = QFileDialog.getOpenFileName(self.dialog, 'Open file', os.path.dirname(os.path.realpath(__file__)), "Json files (*.json)")[0]
        try:
            with open(fname, "r") as file:
                data = json.load(file)
            
            self.ui.lineEditHost.setText(data['Settings']['SQL']['Host'])
            self.ui.lineEditDB.setText(data['Settings']['SQL']['Database'])
            self.ui.spinBoxPort.setValue(int(data['Settings']['SQL']['Port']))
            self.ui.lineEditUser.setText(data['Settings']['SQL']['Username'])
            self.ui.lineEditPassword.setText(data['Settings']['SQL']['Password'])
            self.ui.lineEditTable.setText(data['Settings']['SQL']['Table'])
        except Exception as e:
            print("Error while write configuration:", e)
    def writeConfiguration(self):
        try:
            fname = QFileDialog.getSaveFileName(self.dialog, 'Save file', os.path.dirname(os.path.realpath(__file__)), "Json files (*.json)")[0]
            toJson = {'Host':self.ui.lineEditHost.text(), 'Database':self.ui.lineEditDB.text(), 'Port':str(self.ui.spinBoxPort.value()), 'User':self.ui.lineEditUser.text(), 'Password':self.ui.lineEditPassword.text(), 'Table':self.ui.lineEditTable.text()}
            with open(fname, "w") as file:
                json.dump(toJson, file)
        except Exception as e:
            print("Error while write configuration:", e)
    def checkConnection(self):
        self.ui.parameters = DatabaseMYSQL.ParameterConnection(
            user = self.ui.lineEditUser.text(),
            password = self.ui.lineEditPassword.text(),
            host = self.ui.lineEditHost.text(),
            database = self.ui.lineEditDB.text(),
            table = self.ui.lineEditTable.text(),
            port = self.ui.spinBoxPort.value())
        return DatabaseMYSQL.parametersIsValid(self.ui.parameters)
    
    def save(self):
        try:
            self.checkConnection()
            self.flagParametersReady = True
            self.dialog.close()
        except:
            msgBox = QMessageBox()
            msgBox.setText("Connection is unvalid")
            msgBox.setWindowTitle("Status connection")
            msgBox.exec()
            self.flagParametersReady = False
    
    def cancel(self):
        self.flagParametersReady = False
        self.dialog.close()
        
    def show(self):
        self.dialog.exec()


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    connectionConfiguration = ConnectionConfiguration()
    connectionConfiguration.show()
    sys.exit(app.exec())
    
    





from pip import main
import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

# Есть много элементов конфигурации, некоторые из них не нужны, обратитесь к официальному документу https://packaging.python.org/guides/distributing-packages-using-setuptools/
setuptools.setup(
    name="neofti_ticsummary", # Имя проекта, который будет установлен через pip install hs_rpc в будущем и не может быть повторен с другими проектами, иначе загрузка не удастся
    version="0.0.8", # Номер версии проекта, решайте сами
    author="DmitryKorovkin", # Автор
    author_email="d.korovkin69@gmail.com", # email
    description="TIC data viewer",  # Описание Проекта
    long_description=long_description, # Загружаем содержимое read_me
    long_description_content_type="text/markdown", # Тип текста описания
    url="",  # Адрес проекта, например адрес github или gitlib
    packages= ['ticsummary'], #setuptools.find_packages(''),  # Эта функция может помочь вам найти все файлы в пакете, вы можете указать вручную
    classifiers=[  
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ], # Этот пакет совместим только с Python 3, под лицензией MIT, и не имеет ничего общего с операционной системой. Вы всегда должны включать по крайней мере версию Python, используемую вашим пакетом, лицензию, доступную для пакета, и операционную систему, которую ваш пакет будет использовать. Полный список классификаторов см. На https://pypi.org/classifiers/.
    install_requires=[
        'pyqtgraph',
        'numpy',
        'pyqt6',
        'wrapt_timeout_decorator',
        'mysql',
        'mysql-connector-python'
    ], # Зависимости проекта, вы также можете указать зависимую версию
)